==> koi-1.1.1.tar.gz: koi-1.1.1/lib/kLog/kLog.h <==
/*
 * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
 * Yokogawa Electric Corporation.
 * All rights reserved.
 * 
 * Redistribution and use of this software in source and binary
 * forms, with or without modification, are permitted provided that
 * the following conditions and disclaimer are agreed and accepted
 * by the user:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with
 *    the distribution.
 * 
 * 3. Neither the names of the copyrighters, the name of the project
 *    which is related to this software (hereinafter referred to as
 *    "project") nor the names of the contributors may be used to
 *    endorse or promote products derived from this software without
 *    specific prior written permission.
 * 
 * 4. No merchantable use may be permitted without prior written
 *    notification to the copyrighters.
 * 
 * 5. The copyrighters, the project and the contributors may prohibit
 *    the use of this software at any time.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHTERS, THE PROJECT AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING
 * BUT NOT LIMITED THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE, ARE DISCLAIMED.  IN NO EVENT SHALL THE
 * COPYRIGHTERS, THE PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * $TAHI: koi/lib/kLog/kLog.h,v 1.9 2007/04/06 01:32:08 akisada Exp $
 */

#ifndef _K_LOG_H_
#define _K_LOG_H_

#define L_DEFAULTLEVEL	L_INFO			/* default log level */

#ifndef USE_SYSLOG
#define L_MSGLEN		(256)			/* 1 line log length */
#define L_MSGHEADERLEN	(32)			/* level, time and so on */
#define L_LEVELLEN		(8)				/* level string length for buffer */

#define L_WDEBUG		"DBG"
#define L_WINFO			"INF"
#define L_WWARNING		"WAR"
#define L_WERROR		"ERR"

/* log section */
#ifndef _PATH_KOID_LOG
#define _PATH_KOID_LOG	"/tmp/koid.log"	/* default log filename */
#endif	/* _PATH_KOID_LOG */
#define L_FILENAMELEN	(256)			/* log filename length */
#endif	/* USE_SYSLOG */
#endif	/* _K_LOG_H_ */

==> koi-2.2.0.tar.gz: koi-2.2.0/lib/kLog/kLog.h <==
/*
 *
 * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010
 * NTT Advanced Technology, Yokogawa Electric Corporation.
 * All rights reserved.
 * 
 * Redistribution and use of this software in source and binary
 * forms, with or without modification, are permitted provided that
 * the following conditions and disclaimer are agreed and accepted
 * by the user:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with
 *    the distribution.
 * 
 * 3. Neither the names of the copyrighters, the name of the project
 *    which is related to this software (hereinafter referred to as
 *    "project") nor the names of the contributors may be used to
 *    endorse or promote products derived from this software without
 *    specific prior written permission.
 * 
 * 4. No merchantable use may be permitted without prior written
 *    notification to the copyrighters.
 * 
 * 5. The copyrighters, the project and the contributors may prohibit
 *    the use of this software at any time.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHTERS, THE PROJECT AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING
 * BUT NOT LIMITED THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE, ARE DISCLAIMED.  IN NO EVENT SHALL THE
 * COPYRIGHTERS, THE PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * $TAHI: koi/lib/kLog/kLog.h,v 1.9 2007/04/06 01:32:08 akisada Exp $
 *
 * $Id: kLog.h,v 1.3 2008/06/03 07:39:56 akisada Exp $
 *
 */

#ifndef _K_LOG_H_
#define _K_LOG_H_

#define L_DEFAULTLEVEL	L_WARNING			/* default log level */

#ifndef USE_SYSLOG
#define L_MSGLEN		(256)			/* 1 line log length */
#define L_MSGHEADERLEN	(32)			/* level, time and so on */
#define L_LEVELLEN		(8)				/* level string length for buffer */

#define L_WDEBUG		"DBG"
#define L_WINFO			"INF"
#define L_WWARNING		"WAR"
#define L_WERROR		"ERR"

/* log section */
#ifndef _PATH_KOID_LOG
#define _PATH_KOID_LOG	"/tmp/koid.log"	/* default log filename */
#endif	/* _PATH_KOID_LOG */
#define L_FILENAMELEN	(256)			/* log filename length */
#endif	/* USE_SYSLOG */
#endif	/* _K_LOG_H_ */
